@@ -126,6 +126,11 @@ bool CameraKey::doShortPress()
         launcher->TextReflow();
     if (shortPress.compare("rotation")==0)
         launcher->Rotation();
+    if (shortPress.compare("mediaplayernext")==0)
+        launcher->MediaPlayerNext();
+    if (shortPress.compare("mediaplayerpause")==0)
+        launcher->MediaPlayerTogglePause();
+
 
 	return true;
 }
@@ -151,6 +156,10 @@ bool CameraKey::doLongPress()
         launcher->TextReflow();
     if (longPress.compare("rotation")==0)
         launcher->Rotation();
+    if (longPress.compare("mediaplayernext")==0)
+        launcher->MediaPlayerNext();
+    if (longPress.compare("mediaplayerpause")==0)
+        launcher->MediaPlayerTogglePause();
 
 
 	return true;
