@@ -9,14 +9,15 @@ Config::Config(ProximitySensor* ps_, CameraKey* ck_)
 
 
 	// defaults
+	proximityVibrateOn=1;
 	proximityOn = 0;
 	camerakeyOn = 1;
 	ps_shortPress = "dashboard";
 	ps_longPress = "phone";
-	ps_hold = "proximityToggle";
+	ps_hold = "disabled";
 	ck_shortPress = "dashboard";
 	ck_longPress = "phone";
-
+	shellCommand = "";
 
 	input = fopen(configFile,"r");
 	if(input) {
@@ -51,12 +52,23 @@ void Config::writeConfigFile()
 	std::ofstream f;
 	f.open(configFile);
 
+	std::string shellEscaped = "";
+	for( unsigned int i=0; i<shellCommand.length(); i++ )
+	{
+		if( shellCommand.at(i)=='\"' ) {
+			shellEscaped += "\\";
+		}
+		shellEscaped += shellCommand.at(i);
+	}
+
   	if (f.is_open())
   	{
 		DebugPrint("creating config file");
     		f << "{\n";
     		f << "\"proximityOn\": " << proximityOn << ",";
 		f << "\n";
+    		f << "\"proximityVibrateOn\": " << proximityVibrateOn << ",";
+		f << "\n";
 		f << "\"camerakeyOn\": " << camerakeyOn << ",";
 		f << "\n";
 		f << "\"proximityShortPress\": \"" << ps_shortPress << "\",";
@@ -67,9 +79,11 @@ void Config::writeConfigFile()
 		f << "\n";
 		f << "\"camerakeyShortPress\": \"" << ck_shortPress << "\",";
 		f << "\n";
-		f << "\"camerakeyLongPress\": \"" << ck_longPress << "\"";
+		f << "\"camerakeyLongPress\": \"" << ck_longPress << "\",";
 		f << "\n";
-    		f << "}\n";
+		f << "\"shellCommand\": \"" << shellEscaped << "\"";
+		f << "\n";
+   		f << "}\n";
 		f.close();
   	}
 	chown(configFile,29999,29999);
@@ -138,7 +152,14 @@ void Config::setInt(int value_)
 		proximityOn=value_;	
    	 if (key.compare("camerakeyOn")==0)
 		camerakeyOn=value_;
-	
+   	 if (key.compare("proximityVibrateOn")==0)
+		proximityVibrateOn=value_;
+
+	if( ps != NULL )
+	{
+		ps->vibrateOn=proximityVibrateOn;
+	}
+
 	DebugPrint("config SET: ");
 	DebugPrint(key);
 	DebugPrint(value_);
@@ -158,6 +179,8 @@ void Config::setString(std::string value_)
 		ck_shortPress=value_;
 	if (key.compare("camerakeyLongPress")==0)
 		ck_longPress=value_;
+	if (key.compare("shellCommand")==0)
+		shellCommand=value_;
 
 	if( ps != NULL )
 	{
