@@ -52,6 +52,8 @@ bool Launcher::Init()
 	stc_win = win;
 	stc_grab = FALSE;
 
+    mediaPlayerIsPaused = false;
+
 
 return true;
 }
@@ -277,6 +279,32 @@ bool Launcher::userMenu()
 }
 
 
+/**
+ * Plays the next song in the Maemo media player.
+ */
+bool Launcher::MediaPlayerNext()
+{
+	execShellCommand("dbus-send --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.renderer.next");
+    return true;
+}
+
+
+/**
+ * Toggles Play/Pause in the Maemo media player.
+ */
+bool Launcher::MediaPlayerTogglePause()
+{
+    if (mediaPlayerIsPaused) {
+        execShellCommand("dbus-send --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.renderer.resume");
+        mediaPlayerIsPaused = false;
+    } else {
+        execShellCommand("dbus-send --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.renderer.pause");
+        mediaPlayerIsPaused = true;
+    }
+    return true;
+}
+
+
 bool Launcher::shellCommand()
 {
 	return execShellCommand(defaultShellCommand);
