@@ -37,6 +37,8 @@ class Launcher
 	bool Phone();
 	bool Menu();
 	bool userMenu();
+    bool MediaPlayerNext();
+    bool MediaPlayerTogglePause();
 	bool shellCommand();
 
 	bool switchToDesktop();
@@ -73,6 +75,7 @@ class Launcher
                 int stat;
                 dbus_uint32_t level;
                 const char* paramPhone;
+                bool mediaPlayerIsPaused;
 
 		bool connectToDbusPhone();
 
