@@ -107,6 +107,8 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	launch_descriptions.push_back("Ctrl-shift-r (Enable rotation)");
 	//launch_descriptions.push_back("Browser text reflow");
 	//launch_descriptions.push_back("Shortcutd user menu");
+    launch_descriptions.push_back("MediaPlayer: next song");
+	launch_descriptions.push_back("MediaPlayer: play/pause");
 	launch_descriptions.push_back("Custom shell command");
 	launch_descriptions.push_back("Desktop");
 
@@ -119,6 +121,8 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	launch_actions.push_back("rotation");
 	//launch_actions.push_back("textreflow");
 	//launch_actions.push_back("usermenu");
+    launch_actions.push_back("mediaplayernext");
+	launch_actions.push_back("mediaplayerpause");
 	launch_actions.push_back("shellcommand");
 	launch_actions.push_back("desktop");
 
