@@ -391,6 +391,10 @@ void ProximitySensor::doShortPress()
 		launcher->TextReflow();
     if (shortPress.compare("rotation")==0)      
         launcher->Rotation();
+    if (shortPress.compare("mediaplayernext")==0)
+        launcher->MediaPlayerNext();
+    if (shortPress.compare("mediaplayerpause")==0)
+        launcher->MediaPlayerTogglePause();
 
 }
 
@@ -414,6 +418,11 @@ void ProximitySensor::doLongPress()
     	launcher->TextReflow();
     if (longPress.compare("rotation")==0)
         launcher->Rotation();
+    if (longPress.compare("mediaplayernext")==0)
+        launcher->MediaPlayerNext();
+    if (longPress.compare("mediaplayerpause")==0)
+        launcher->MediaPlayerTogglePause();
+
 }
 
 
